==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/PasswordPolicyRecoverySettings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordPolicyRecoveryFactors;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordPolicyRecoverySettings
 */
@JsonPropertyOrder({ PasswordPolicyRecoverySettings.JSON_PROPERTY_FACTORS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PasswordPolicyRecoverySettings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_FACTORS = "factors";
    private PasswordPolicyRecoveryFactors factors;

    public PasswordPolicyRecoverySettings() {
    }

    public PasswordPolicyRecoverySettings factors(PasswordPolicyRecoveryFactors factors) {

        this.factors = factors;
        return this;
    }

    /**
     * Get factors
     *
     * @return factors
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_FACTORS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryFactors getFactors() {
        return factors;
    }

    @JsonProperty(JSON_PROPERTY_FACTORS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setFactors(PasswordPolicyRecoveryFactors factors) {
        this.factors = factors;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordPolicyRecoverySettings passwordPolicyRecoverySettings = (PasswordPolicyRecoverySettings) o;
        return Objects.equals(this.factors, passwordPolicyRecoverySettings.factors);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(factors);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordPolicyRecoverySettings {\n");
        sb.append("    factors: ").append(toIndentedString(factors)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/PasswordPolicyRecoverySettings.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordPolicyRecoveryFactors;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordPolicyRecoverySettings
 */
@JsonPropertyOrder({ PasswordPolicyRecoverySettings.JSON_PROPERTY_FACTORS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PasswordPolicyRecoverySettings implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_FACTORS = "factors";
    private PasswordPolicyRecoveryFactors factors;

    public PasswordPolicyRecoverySettings() {
    }

    public PasswordPolicyRecoverySettings factors(PasswordPolicyRecoveryFactors factors) {

        this.factors = factors;
        return this;
    }

    /**
     * Get factors
     *
     * @return factors
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_FACTORS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryFactors getFactors() {
        return factors;
    }

    @JsonProperty(JSON_PROPERTY_FACTORS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setFactors(PasswordPolicyRecoveryFactors factors) {
        this.factors = factors;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordPolicyRecoverySettings passwordPolicyRecoverySettings = (PasswordPolicyRecoverySettings) o;
        return Objects.equals(this.factors, passwordPolicyRecoverySettings.factors);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(factors);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordPolicyRecoverySettings {\n");
        sb.append("    factors: ").append(toIndentedString(factors)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
